import click
import time
from app.timer import Timer
from playsound import playsound

SHORT_ALARM = 'app/alarms/sbalarm.mp3'
START_ALARM = 'app/alarms/stalarm.mp3'
END_ALARM = 'app/alarms/endalarm.mp3'


def run_timer(minutes, msg):
    t = Timer()
    t.start()
    while t.current_time() < minutes:
        click.echo(f"{int(t.current_time())}: {msg}")
        time.sleep(1)
    t.stop()


def start_session(_s, short_breaks, focus):
    click.echo(f"Starting work Session {_s +1} of {short_breaks}")
    run_timer(focus, "Focus...")


def short_break(_s, short_breaks, short):
    playsound(SHORT_ALARM)
    click.echo(f'Starting long break! {_s +1} of {short_breaks}')
    run_timer(short, "Take a short break!")
    if (_s + 1) != short_breaks:
        playsound(START_ALARM)


def long_break(_l, long_breaks, long):
    click.echo(f'Starting long break! {_l +1} of {long_breaks}')
    run_timer(long, "Take a long break!")
    if (_l+1) != long_breaks:
        playsound(START_ALARM)


def completed():
    click.echo("Doro Completed")
    playsound(END_ALARM)



import click
from app.application import run_timer, start_session, short_break, long_break, completed


@click.group()
def cli():
    pass


@cli.command()
@click.option('-f', '--focus', default="25", help='Time between breaks in minutes')
@click.option('-s', '--short', default="5", help='Short break length in minutes')
@click.option('-l', '--long', default="25", help='Long break taken after 4 focus+short pomodoro intervals in minutes')
@click.option('-bs', '--breaks', default='4', help='Number of long breaks in minutes')
def custom(focus, short, long, breaks):

    long_breaks = int(breaks)
    short_breaks = 4
    focus = int(focus)*60
    short = int(short)*60
    long = int(long)*60

    for _l in range(long_breaks):
        for _s in range(short_breaks):

            start_session(_s, short_breaks, focus)

            short_break(_s, short_breaks, short)

        long_break(_l, long_breaks, long)

    completed()


@cli.command()
@click.option('-bs', '--breaks', default='4', help='Number of long breaks')
def start(breaks):
    long_breaks = int(breaks)
    short_breaks = 4
    twenty_five_min = 1500
    five_min = 300

    for _l in range(long_breaks):
        for _s in range(short_breaks):

            start_session(_s, short_breaks, twenty_five_min)

            short_break(_s, short_breaks, five_min)

        long_break(_l, long_breaks, twenty_five_min)

    completed()


@cli.command()
@click.option('-m', '--minutes', default='30', help='Number of minutes')
def timer(minutes):
    run_timer(int(minutes)*60, 'Timer Running...')
    completed()


@cli.command()
def hour():
    run_timer(60*60, 'Timer Running...')
    completed()


@cli.command()
def half():
    run_timer(30*60, 'Timer Running...')
    completed()



from setuptools import setup, find_packages

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

with open("requirements.txt", "r", encoding="utf-8") as fh:
    requirements = fh.read()

setup(
    name='Pmdr',
    version='1.0.2',
    author='Jeff Salisbury',
    author_email='salisbury.jeffery@gmail.com',
    license='MIT',
    description='CLI Pomodoro Timer',
    long_description=long_description,
    long_description_content_type="text/markdown",
    url='https://github.com/JDSalisbury/doro',
    py_modules=['timer', 'app'],
    packages=find_packages(),
    install_requires=[requirements],
    python_requires='>=3.7',
    classifiers=["Programming Language :: Python :: 3.8",
                 "Operating System :: OS Independent"],
    entry_points='''
        [console_scripts]
        pmdr=timer:cli
    '''
)



import time


class TimerError(Exception):
    """A custom exception used to report errors in use of Timer class"""


class Timer:
    def __init__(self):
        self._start_time = None

    def start(self):
        """Start a new timer"""
        if self._start_time is not None:
            raise TimerError(f"Timer is running. Use .stop() to stop it")

        self._start_time = time.perf_counter()

    def current_time(self):
        return time.perf_counter() - self._start_time

    def stop(self):
        """Stop the timer, and report the elapsed time"""
        if self._start_time is None:
            raise TimerError(f"Timer is not running. Use .start() to start it")

        elapsed_time = time.perf_counter() - self._start_time
        self._start_time = None
        print(f"Elapsed time: {int(elapsed_time)} seconds")
        return elapsed_time
